@@ -23,7 +23,7 @@ VM_OPTS="-Xmx1024m"
 
 RELEX_OPTS="\
 	-Djava.library.path=/usr/lib:/usr/lib/jni:/usr/local/lib:/usr/local/lib/jni \
-	-Drelex.algpath=data/relex-semantic-algs.txt \
+	-Drelex.algpath=data/relex-semantic.algs \
 	-Dwordnet.configfile=data/wordnet/file_properties.xml \
 	"
 
@@ -46,6 +46,14 @@ bin:\
 "
 # java $VM_OPTS $RELEX_OPTS $CLASSPATH relex.Server --link --relex --anaphora --verbose
 
+# This will return parsed text on the input socket.
 java $VM_OPTS $RELEX_OPTS $CLASSPATH relex.Server --relex --anaphora --port 4444
 
+# This will send the parsed output to an opencog server on localhost at port 17001
+# java $VM_OPTS $RELEX_OPTS $CLASSPATH relex.Server --relex --port 4444 --host localhost:17001
+
+# This will send the RelEx OpenCog output and the RelEx2Logic function calls to
+# an opencog server on localhost at port 17001
+# java $VM_OPTS $RELEX_OPTS $CLASSPATH relex.Server --logic --port 4444 --host localhost:17001
+
 
