@@ -1,6 +1,4 @@
 /*
- * Copyright 2008 Novamente LLC
- *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -12,6 +10,9 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ *
+ * Copyright (c) 2008 Novamente LLC
+ * Copyright (c) 2008, 2009 Linas Vepstas <linasvepstas@gmail.com>
  */
 
 package relex;
@@ -63,7 +64,7 @@ public class ParsedSentence
 	private String idString;
 
 	// Back-pointer to collection of other parses for this sentence
-	private Sentence sentence;
+	private Sentence _sentence;
 
 	// String containing the original sentence
 	private String original;
@@ -119,11 +120,11 @@ public class ParsedSentence
 	}
 
 	public Sentence getSentence() {
-		return sentence;
+		return _sentence;
 	}
 
 	public void setSentence(Sentence s) {
-		sentence = s;
+		_sentence = s;
 	}
 
 	public void setIDString(String str) {
