@@ -1,6 +1,4 @@
 /*
- * Copyright 2008 Novamente LLC
- *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -12,6 +10,9 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ *
+ * Copyright (c) 2008 Novamente LLC
+ * Copyright (c) 2008, 2009, 2013 Linas Vepstas <linasvepstas@gmail.com>
  */
 package relex;
 
@@ -105,13 +106,16 @@ public class RelationExtractor
 	/** Document - holder of sentences */
 	Document doco;
 
+	/** Apply the relex algs to the parse */
+	public boolean do_apply_algs;
+
 	/** Stanford parser compatibility mode */
 	public boolean do_stanford;
 
 	/** Penn tagset compatibility mode */
 	public boolean do_penn_tagging;
 
-	/** Expand preposition markup to two dependencies. */
+	/** Expand preposition markup into two dependencies. */
 	public boolean do_expand_preps;
 
 	/** Statistics */
@@ -130,6 +134,7 @@ public class RelationExtractor
 		do_anaphora_resolution = false;
 		do_tree_markup = false;
 
+		do_apply_algs = true;
 		do_stanford = false;
 		do_penn_tagging = false;
 		do_expand_preps = false;
@@ -151,11 +156,18 @@ public class RelationExtractor
 		if (_is_inited) return;
 		_is_inited = true;
 
+		// At this time, we only have algs for English.
+		// So, don't waste CPU time on algs if its not English.
+		if (null != _lang && "en" != _lang) do_apply_algs = false;
+
 		parser = _use_sock ? new RemoteLGParser() : new LocalLGParser();
 		if (null != _lang) parser.setLanguage(_lang);
 		if (null != _dict_path) parser.setDictPath(_dict_path);
 		parser.getConfig().setStoreConstituentString(true);
 		parser.getConfig().setStoreSense(true);
+
+		// XXX TODO: this is loading the English Language morphy;
+		// we need to load a generic language handler.
 		Morphy morphy = MorphyFactory.getImplementation(MorphyFactory.DEFAULT_SINGLE_THREAD_IMPLEMENTATION);
 		context = new RelexContext(parser, morphy);
 
@@ -195,8 +207,9 @@ public class RelationExtractor
 	/* Control parameters, etc. */
 	/**
 	 * Set the max number of parses.
-	 * This will NOT reduce processing time; all parses are still computed,
-	 * but only this many are returned.
+	 * This will NOT reduce processing time; up to 1000 parses are
+	 * still computed, but only this many are returned.  To reduce
+	 * processing time, use setMaxLinkages below.
 	 */
 	public void setMaxParses(int maxParses)
 	{
@@ -204,6 +217,28 @@ public class RelationExtractor
 		parser.getConfig().setMaxLinkages(maxParses);
 	}
 
+	/**
+	 * Set the max number of parses that are computed.
+	 * Default: 1000; default is set in link-grammar/jni-client.c
+	 *
+	 * Sets the max number of linkages (parses) that are computed by
+	 * link-grammar. This should be set to a value that is significantly
+	 * larger than the expected number of parses for a sentence.  Setting
+	 * this below 1000 is strongly discourged, you won't get what you want.
+	 * Use setMaxParses() above to control the number of parses displayed.
+	 *
+	 * Caution: Setting this number too low will result in a **random**
+	 * subset of possible linakges to be explored. This random subset
+	 * might not include the best (highest-scoring) linkages, which is
+	 * probably not what you want. This method is here really so as to
+	 * increase the number of linakges about 1000 (for the ANY language).
+	 */
+	public void setMaxLinkages(int maxLinkages)
+	{
+		if (!_is_inited) init();
+		parser.setMaxLinkages(maxLinkages);
+	}
+
 	public void setMaxCost(int maxCost)
 	{
 		if (!_is_inited) init();
@@ -259,7 +294,7 @@ public class RelationExtractor
 				}
 
 				// The actual relation extraction is done here.
-				sentenceAlgorithmApplier.applyAlgs(parse, context);
+				if (do_apply_algs) sentenceAlgorithmApplier.applyAlgs(parse, context);
 				if (do_stanford) sentenceAlgorithmApplier.extractStanford(parse, context);
 				if (do_penn_tagging) sentenceAlgorithmApplier.pennTag(parse, context);
 
@@ -285,7 +320,7 @@ public class RelationExtractor
 				hobbs.resolve(sntc);
 			}
 		}
-		catch(Exception e)
+		catch (Exception e)
 		{
 			System.err.println("Error: Failed to process sentence: " + sentence);
 			e.printStackTrace();
@@ -386,6 +421,7 @@ public class RelationExtractor
 			" [-h (show this help)]" +
 			" [-i (show output for generation)]" +
 			" [-l (show Link Grammar parse diagram)]" +
+			" [--lang language (default en for English)]" +
 			" [-m (show parse metadata)]" +
 			" [--maxParseSeconds N]" +
 			" [-n max number of parses to display]" +
@@ -426,11 +462,14 @@ public class RelationExtractor
 		HashSet<String> opts = new HashSet<String>();
 		opts.add("-n");
 		opts.add("-s");
-		opts.add("--maxParseSeconds");
 		opts.add("--html");
+		opts.add("--lang");
+		opts.add("--maxParseSeconds");
 		Map<String,String> commandMap = CommandLineArgParser.parse(args, opts, flags);
 
+		// Things that can be set via command line flags; cache till needed.
 		String sentence = null;
+		String language = "en";
 		int maxParses = 1;
 		int maxParseSeconds = 6;
 		PrintWriter html = null;
@@ -444,11 +483,14 @@ public class RelationExtractor
 			opt = commandMap.get("-n");
 			if (opt != null) maxParses = Integer.parseInt(opt);
 
-			opt = commandMap.get("--maxParseSeconds");
-			if (opt != null) maxParseSeconds = Integer.parseInt(opt);
-
 			opt = commandMap.get("--html");
 			if (opt != null) html = new PrintWriter(new FileWriter(opt));
+
+			opt = commandMap.get("--lang");
+			if (opt != null) language = opt;
+
+			opt = commandMap.get("--maxParseSeconds");
+			if (opt != null) maxParseSeconds = Integer.parseInt(opt);
 		}
 		catch (Exception e)
 		{
@@ -471,6 +513,8 @@ public class RelationExtractor
 		if (html != null) html.println("<html>");
 
 		RelationExtractor re = new RelationExtractor();
+		// careful: set language *before* doing other  things, to avoid call to init()
+		re.setLanguage(language);
 		re.setAllowSkippedWords(true);
 		re.setMaxParses(maxParses);
 		re.setMaxParseSeconds(maxParseSeconds);
@@ -536,7 +580,7 @@ public class RelationExtractor
 
 		int sentence_count = 0;
 		boolean more_input = true;
-		while(more_input)
+		while (more_input)
 		{
 			// If no sentence specified on the command line
 			// (with the "-s" flag), then read it from stdin.
@@ -564,6 +608,10 @@ public class RelationExtractor
 			{
 				System.out.println("; SENTENCE: ["+sentence+"]");
 				Sentence sntc = re.processSentence(sentence);
+
+				// Crazy error condition ... the parser is broken somehow ...
+				if (null == sntc) { sentence = ds.getNextSentence(); break; }
+
 				re.doco.addSentence(sntc);
 
 				if (html != null)
@@ -634,8 +682,9 @@ public class RelationExtractor
 					{
 						// Print simple parse ranking
 						Double confidence = parse.getTruthValue().getConfidence();
-						String pconfidence = confidence.toString().substring(0,6);
-						System.out.println("Parse confidence: " + pconfidence);
+						String prt_cnfd = confidence.toString();
+						prt_cnfd = prt_cnfd.substring(0, Math.min(6, prt_cnfd.length()));
+						System.out.println("Parse confidence: " + prt_cnfd);
 						System.out.println(
 							"cost vector = (UNUSED=" + parse.getNumSkippedWords() +
 							" DIS=" + parse.getDisjunctCost() +
@@ -649,7 +698,8 @@ public class RelationExtractor
 						 	parse.getLeft().toString(LinkView.getFilter()));
 
 					if ((commandMap.get("-q") == null) &&
-					    (commandMap.get("-o") == null))
+					    (commandMap.get("-o") == null) &&
+					    re.do_apply_algs)
 					{
 						System.out.println("\n======\n");
 						System.out.println("Dependency relations:\n");
