@@ -18,34 +18,48 @@ package relex.corpus;
 public class DocSplitterFactory
 {
 	private static final Class<? extends DocSplitter> clazz;
-	static{
+	static {
 		Class<? extends DocSplitter> clazz0;
-		clazz0 = DocSplitterFallbackImpl.class;
-		// This is what opennlp-1.5.0 uses
-		// Except that I can't figure out how to load the model,
-		// when I run 1.5.0. So, for now, stub this out. 
-		// try
-		// {
-		// 	Class.forName("opennlp.tools.sentdetect.SentenceDetectorME");
-		// }
-		// catch(Throwable t)
-		// {
-		// }
+		clazz0 = null;
+
+		// First, try to load opennlp-1.5.0
 		try
 		{
-			// If the above isn't found, try again ... 
-			// This is what opennlp-1.4.3 and 1.3.0 use.
-			Class.forName("opennlp.tools.lang.english.SentenceDetector");
+			// Earlier versions of opennlp don't have this class,
+			// and so we'll throw an error if its not found.
+			Class.forName("opennlp.tools.sentdetect.SentenceModel");
 
-			// clazz0 = DocSplitterOpenNLPImpl.class;
-			Class<?> c = Class.forName("relex.corpus.DocSplitterOpenNLPImpl");
+			// clazz0 = DocSplitterOpenNLP15Impl.class;
+			Class<?> c = Class.forName("relex.corpus.DocSplitterOpenNLP15Impl");
 
 			// It seems to be impossible to perform this cast and not get
 			// a type-safety warning,
 			clazz0 = (Class<DocSplitter>) c;
 		}
-		catch(Throwable t2)
+		catch(Throwable t) {}
+
+		// Try again, this time looking for opennlp-tools-1.4.x or 1.3.x
+		if (null == clazz0)
 		{
+			try
+			{
+				// If the above isn't found, try again ...
+				// This is what opennlp-1.4.3 and 1.3.0 use.
+				Class.forName("opennlp.tools.lang.english.SentenceDetector");
+
+				// clazz0 = DocSplitterOpenNLPImpl.class;
+				Class<?> c = Class.forName("relex.corpus.DocSplitterOpenNLP14Impl");
+
+				// It seems to be impossible to perform this cast and not get
+				// a type-safety warning,
+				clazz0 = (Class<DocSplitter>) c;
+			}
+			catch(Throwable t2) {}
+		}
+
+		if (null == clazz0)
+		{
+			clazz0 = DocSplitterFallbackImpl.class;
 			System.err.println(
 				"\nWARNING:\n" +
 				"\tIt appears that the OpenNLP tools are not installed or are not\n" +
@@ -66,7 +80,7 @@ public class DocSplitterFactory
 				System.err.println(
 					"\nWARNING:\n" +
 					"\tIt appears that the DocSplitter class is not working for some reason.\n" +
-					"\tMake sure that data/sentence-detector/EnglishSD.bin.gz is installed\n" +
+					"\tMake sure that data/opennlp/models-1.5/en-sent.bin is installed\n" +
 					"\tor that an alternate location is specified with -DEnglishModelFilename\n" +
 					"\tin the script/run files.\n" +
 					"\tWithout it, ReleEx will use the less-accurate Java native sentence detector.\n" +
