@@ -18,6 +18,9 @@ package relex.feature;
 
 import java.util.ArrayList;
 
+import relex.stats.SimpleTruthValue;
+import relex.stats.TruthValue;
+
 /**
  * Holder of lists of feature nodes.
  *
@@ -27,9 +30,9 @@ import java.util.ArrayList;
 public class Chunk extends Atom
 {
 	private static final long serialVersionUID = -684476296428342726L;
-	
+
 	protected ArrayList<FeatureNode> chunk;
-	
+
 	public Chunk()
 	{
 		chunk = new ArrayList<FeatureNode>();
@@ -65,7 +68,7 @@ public class Chunk extends Atom
 
 			// Add subphrases to the word list
 			FeatureNode subf = fn.get("phr-head");
-			if (subf != null) 
+			if (subf != null)
 			{
 				addPhrase(fn);
 			}
@@ -75,7 +78,7 @@ public class Chunk extends Atom
 
 	/**
 	 * Return true if the other object equals this one, else return false.
-	 * Equals, in the comp-sci sense (e.g. scheme or lisp): compares 
+	 * Equals, in the comp-sci sense (e.g. scheme or lisp): compares
 	 * structure to determine if they have congruent structure.
 	 */
 	public boolean equals(Object other)
@@ -89,4 +92,40 @@ public class Chunk extends Atom
 		}
 		return true;
 	}
+
+	/**
+	 * return the confidence of the chunk.
+	 */
+	public double getConfidence()
+	{
+		TruthValue tv = this.getTruthValue();
+		SimpleTruthValue stv = (SimpleTruthValue) tv;
+		return stv.getConfidence();
+	}
+
+	/**
+	 * Twiddle the confidence of the chunk.
+	 * Multiply the confidence value of the chunk by the weight.
+	 */
+	public void rescaleConfidence(double weight)
+	{
+		TruthValue tv = this.getTruthValue();
+		SimpleTruthValue stv = (SimpleTruthValue) tv;
+		double confidence = stv.getConfidence();
+		confidence *= weight;
+		stv.setConfidence(confidence);
+	}
+
+	/**
+	 * Increment the confidence of the chunk.
+	 * Add the weight to the confidence value of the chunk.
+	 */
+	public void incrementConfidence(double weight)
+	{
+		TruthValue tv = this.getTruthValue();
+		SimpleTruthValue stv = (SimpleTruthValue) tv;
+		double confidence = stv.getConfidence();
+		confidence += weight;
+		stv.setConfidence(confidence);
+	}
 }
