@@ -33,11 +33,11 @@ import relex.feature.FeatureNode;
  * As the same sentence can have multiple parses, this class only
  * displays a single, particular parse.
  *
- * Copyright (C) 2007,2008 Linas Vepstas <linas@linas.org>
+ * Copyright (c) 2007, 2008, 2013 Linas Vepstas <linas@linas.org>
  */
 public class OpenCogScheme
 {
-	private ParsedSentence parse = null;
+	private ParsedSentence _parse = null;
 	private String orig_sentence = null;
 
 	private OpenCogSchemeLink link_scheme;
@@ -66,18 +66,19 @@ public class OpenCogScheme
 	public void setShowAnaphora(boolean flag) { do_show_anaphora = flag; }
 	public boolean getShowAnaphora() { return do_show_anaphora; }
 
-	public void setParse(ParsedSentence _parse)
+	public void setParse(ParsedSentence parse)
 	{
-		parse = _parse;
+		_parse = parse;
 
 		orig_sentence += printWords();
+		orig_sentence += printParse();
 		orig_sentence += printSentence();
 
-		link_scheme.setParse(parse);
-		rel_scheme.setParse(parse);
+		link_scheme.setParse(_parse);
+		rel_scheme.setParse(_parse);
 
 		anaphora_scheme.clear();
-		anaphora_scheme.setSentence(parse);
+		anaphora_scheme.setSentence(_parse);
 	}
 
 	/* -------------------------------------------------------------------- */
@@ -118,22 +119,33 @@ public class OpenCogScheme
 	{
 		String str = "";
 
-		FeatureNode fn = parse.getLeft();
-		fn = fn.get("NEXT");
+		FeatureNode fn = _parse.getLeft();
 		while (fn != null)
 		{
 			String word = fn.get("orig_str").getValue();
 			String guid_word = fn.get("uuid").getValue();
+			if (word.equals("LEFT-WALL"))
+				word = "###LEFT-WALL###";
 
+			if(word.matches("[-+]?[0-9]*?\\.?[0-9]+"))
+			{
+				str += "(ReferenceLink (stv 1.0 1.0)\n" +
+						"   (WordInstanceNode \"" + guid_word + "\")\n" +
+						"   (NumberNode " + word + ")\n" +
+						")\n";
+			}
+			else 
+			{
 			str += "(ReferenceLink (stv 1.0 1.0)\n" +
-			       "   (WordInstanceNode \"" + guid_word + "\")\n" +
-			       "   (WordNode \"" + word + "\")\n" +
-			       ")\n";
+					"   (WordInstanceNode \"" + guid_word + "\")\n" +
+					"   (WordNode \"" + word + "\")\n" +
+					")\n"; 
+			}
 
 			str += "(WordInstanceLink (stv 1.0 1.0)\n" +
-			       "   (WordInstanceNode \"" + guid_word + "\")\n" +
-			       "   (ParseNode \"" + parse.getIDString() + "\")\n" +
-			       ")\n";
+					"   (WordInstanceNode \"" + guid_word + "\")\n" +
+					"   (ParseNode \"" + _parse.getIDString() + "\")\n" +
+					")\n";
 
 			fn = fn.get("NEXT");
 		}
@@ -141,26 +153,48 @@ public class OpenCogScheme
 	}
 
 	/**
-	 * Print the original sentence, as made up out of word instances,
+	 * Print the words in the parse, as made up out of word instances,
 	 * maintaining the proper word order in the sentence.
 	 */
-	public String printSentence()
+	public String printParse()
 	{
 		String str = "(ReferenceLink (stv 1.0 1.0)\n" +
-		             "   (ParseNode \"" + parse.getIDString() + "\")\n" +
-		             "   (ListLink\n";
+					"   (ParseNode \"" + _parse.getIDString() + "\")\n" +
+					"   (ListLink\n";
 
-		FeatureNode fn = parse.getLeft();
+		FeatureNode fn = _parse.getLeft();
 		fn = fn.get("NEXT"); // skip LEFT-WALL
 		while (fn != null)
 		{
 			String guid = fn.get("uuid").getValue();
-			str += "      (WordInstanceNode \"" + guid + "\")\n";
+			str += "     (WordInstanceNode \"" + guid + "\")\n";
 			fn = fn.get("NEXT");
 		}
 
 		str += "   )\n" +
-		       ")\n";
+			  ")\n";
+		return str;
+	}
+
+	/**
+	 * Print a parseLink that attaches a specific parse to the sentence
+	 * that its a part of.  Attach a truth value that represents the 
+	 * parse ranking for the parse.
+	 */
+	public String printSentence()
+	{
+		Double confidence = _parse.getTruthValue().getConfidence();
+
+		// Why the fuck is string formating so fucked in Java? WTF?
+		String scf = confidence.toString();
+		int strl = Math.min(6, scf.length());
+		scf = scf.substring(0, strl);
+
+		String str = "(ParseLink (stv 1 1)\n" +
+					"   (ParseNode \"" + _parse.getIDString() +
+					    "\"(stv 1.0 " + scf + "))\n" +
+				   "   (SentenceNode \"" + _parse.getSentence().getID() + "\")\n" +
+				   ")\n";
 		return str;
 	}
 
@@ -171,14 +205,14 @@ public class OpenCogScheme
 	public String printDocument(Document doco)
 	{
 		String str = "(ReferenceLink (stv 1.0 1.0)\n" +
-		             "   (DocumentNode \"" + doco.getID() + "\")\n" +
-		             "   (ListLink\n";
+				   "   (DocumentNode \"" + doco.getID() + "\")\n" +
+				   "   (ListLink\n";
 
 		ArrayList<Sentence> sentence_list = doco.getSentences();
 		for (int i=0; i<sentence_list.size(); i++)
 		{
 			str += "      (SentenceNode \"" +
-			       sentence_list.get(i).getID() + "\")\n";
+				  sentence_list.get(i).getID() + "\")\n";
 		}
 
 		str += "   )\n" +
