@@ -186,9 +186,17 @@ class OpenCogSchemeRel
 				// The word instance, and its associated lemma form
 				refs += "(LemmaLink (stv 1.0 1.0)\n";
 				refs += "   (WordInstanceNode \"" + guid_word + "\")\n";
-				refs += "   (WordNode \"" + lemma + "\")\n";
-				refs += ")\n";
-			}
+
+				if(lemma.matches("[-+]?[0-9]*?\\.?[0-9]+"))
+				{
+					refs += "   (NumberNode \"" + lemma + "\")\n";
+				}
+				else
+				{
+					refs += "   (WordNode \"" + lemma + "\")\n";
+				}
+					refs += ")\n";
+				}
 
 			fn = fn.get("NEXT");
 			word_index ++;
@@ -199,24 +207,9 @@ class OpenCogSchemeRel
 
 	/* ----------------------------------------------------------- */
 
-	private String printRank()
-	{
-		String ret =
-		"(ParseLink (stv 1 1)\n" +
-		"   (ParseNode \"" + parse.getIDString() + "\" (stv 1.0 ";
-
-		Double confidence = parse.getTruthValue().getConfidence();
-		ret += confidence.toString().substring(0,6) + "))\n" +
-		"   (SentenceNode \"" + parse.getSentence().getID() + "\")\n)\n";
-		return ret;
-	}
-
-	/* ----------------------------------------------------------- */
-
 	public String toString()
 	{
 		String ret = "";
-		ret += printRank();
 		ret += printWordRefs();
 		ret += printRelations();
 		return ret;
